Package: pingr
Title: Check if a Remote Computer is Up
Version: 2.0.5
Authors@R: c(
    person("Gábor", "Csárdi", , "csardi.gabor@gmail.com", role = c("aut", "cre")),
    person("Posit Software, PBC", role = c("cph", "fnd"))
  )
Description: Check if a remote computer is up. It can either just call the
    system ping command, or check a specified TCP port.
License: MIT + file LICENSE
URL: https://r-lib.github.io/pingr/, https://github.com/r-lib/pingr
BugReports: https://github.com/r-lib/pingr/issues
Depends: R (>= 3.6)
Imports: processx, utils
Suggests: covr, ps, testthat (>= 3.0.0)
Config/Needs/website: tidyverse/tidytemplate
Config/testthat/edition: 3
Encoding: UTF-8
RoxygenNote: 7.2.3
Biarch: true
NeedsCompilation: yes
Packaged: 2024-12-12 09:19:43 UTC; gaborcsardi
Author: Gábor Csárdi [aut, cre],
  Posit Software, PBC [cph, fnd]
Maintainer: Gábor Csárdi <csardi.gabor@gmail.com>
Repository: CRAN
Date/Publication: 2024-12-12 10:10:02 UTC
